@@ -13,6 +13,7 @@ using namespace DDLog;
 CpuProfile::CpuProfile(QObject *parent)
     : QObject(parent), mCpuUsage(0.0)
 {
+    qCDebug(app) << "CpuProfile constructor";
     // mLastCpuStat用于记录Cpu状态
     // 各项数值是开机后各项工作的时间片总数
     // 初始化mLastCpuStat
@@ -35,11 +36,13 @@ CpuProfile::CpuProfile(QObject *parent)
 
 double CpuProfile::updateSystemCpuUsage()
 {
+    qCDebug(app) << "updateSystemCpuUsage";
     // 返回值，Cpu占用率
     double cpuUsage = 0.0;
 
     QFile file(PROC_CPU_STAT_PATH);
     if (file.exists() && file.open(QFile::ReadOnly)) {
+        qCDebug(app) << "Reading CPU statistics from" << PROC_CPU_STAT_PATH;
         // 计算总的Cpu占用率，只需要读取第一行数据
         QByteArray lineData = file.readLine();
         file.close();
@@ -55,9 +58,11 @@ double CpuProfile::updateSystemCpuUsage()
 
         // CPU状态应包含10个数据片段，有效数据 1-10，位置0不使用
         if (cpuStatus.size() < 11) {
+            qCWarning(app) << "Invalid CPU status data format. Expected 11 fields, got" << cpuStatus.size();
             return cpuUsage;
         }
 
+        qCDebug(app) << "cpuStatus data is valid";
         // 构建数据map，便于后期数据计算方式需求变更
         QMap<QString, int> curCpuStat;
         {
@@ -87,19 +92,21 @@ double CpuProfile::updateSystemCpuUsage()
                 (curCpuStat["idle"] + curCpuStat["iowait"]) - (mLastCpuStat["idle"] + mLastCpuStat["iowait"]);
 
         if (calcCpuTotal == 0.0) {
-            qCWarning(app) << " cpu total usage calc result equal 0 ! cpu stat [" << curCpuStat << "]";
+            qCWarning(app) << "CPU total usage calculation result is 0. Current CPU stats:" << curCpuStat;
             return cpuUsage;
         }
+        qCDebug(app) << "calcCpuTotal is not 0";
         // 上一个时间段内的Cpu使用情况
         cpuUsage = (calcCpuTotal - calcCpuIdle) * 100.0 / calcCpuTotal;
 
         // 更新Cpu占用率
         mCpuUsage = cpuUsage;
+        qCDebug(app) << "Updated CPU usage:" << cpuUsage << "%";
 
         // 更新上一次CPU状态
         mLastCpuStat = curCpuStat;
     } else {
-        qCWarning(app) << QString(" file %1 open fail !").arg(PROC_CPU_STAT_PATH);
+        qCWarning(app) << "Failed to open CPU statistics file:" << PROC_CPU_STAT_PATH;
     }
 
     return cpuUsage;
@@ -107,10 +114,12 @@ double CpuProfile::updateSystemCpuUsage()
 
 QMap<QString, int> CpuProfile::cpuStat()
 {
+    // qCDebug(app) << "cpuStat";
     return mLastCpuStat;
 }
 
 double CpuProfile::getCpuUsage()
 {
+    // qCDebug(app) << "getCpuUsage";
     return mCpuUsage;
 }
