@@ -1,8 +1,10 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="ug">
 <context>
     <name>Common.Search</name>
     <message>
-        <location filename="../gui/process_table_view.cpp" line="130"/>
+        <location filename="../gui/process_table_view.cpp" line="141"/>
         <source>No search results</source>
         <translation>ئىزدەش نەتىجىسى يوق</translation>
     </message>
@@ -10,7 +12,7 @@
 <context>
     <name>Cpu.Widget</name>
     <message>
-        <location filename="../gui/cpu_widget.cpp" line="180"/>
+        <location filename="../gui/cpu_widget.cpp" line="193"/>
         <source>CPU</source>
         <translation>بىر تەرەپ قىلغۇچ</translation>
     </message>
@@ -18,8 +20,9 @@
 <context>
     <name>CpuWidget</name>
     <message>
-        <location filename="../gui/cpu_widget.cpp" line="216"/>
-        <location filename="../gui/cpu_widget.cpp" line="217"/>
+        <location filename="../gui/cpu_widget.cpp" line="229"/>
+        <location filename="../gui/cpu_widget.cpp" line="231"/>
+        <location filename="../gui/cpu_widget.cpp" line="232"/>
         <source>Utilization</source>
         <translation>پايدىلىنىشچانلىقى</translation>
     </message>
@@ -27,49 +30,36 @@
 <context>
     <name>Disk.Widget</name>
     <message>
-        <location filename="../gui/disk_widget.cpp" line="228"/>
+        <location filename="../gui/disk_widget.cpp" line="242"/>
         <source>Disk</source>
         <translation>دىسكا</translation>
     </message>
     <message>
-        <location filename="../gui/disk_widget.cpp" line="258"/>
+        <location filename="../gui/disk_widget.cpp" line="276"/>
         <source>Read</source>
         <translation>ئوقۇش</translation>
     </message>
     <message>
-        <location filename="../gui/disk_widget.cpp" line="259"/>
+        <location filename="../gui/disk_widget.cpp" line="277"/>
         <source>Write</source>
         <translation>يېزىش</translation>
     </message>
 </context>
-<context>
-    <name>Help.Shortcut.System</name>
-    <message>
-        <location filename="../common/common.cpp" line="42"/>
-        <source>System</source>
-        <translation>سىستېما</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="48"/>
-        <source>Display shortcuts</source>
-        <translation>تېزلەتمە كۆرسەت</translation>
-    </message>
-</context>
 <context>
     <name>Memory.Widget</name>
     <message>
-        <location filename="../gui/memory_widget.cpp" line="152"/>
+        <location filename="../gui/memory_widget.cpp" line="178"/>
         <source>Memory</source>
         <translation>ساقلىغۇ</translation>
     </message>
     <message>
-        <location filename="../gui/memory_widget.cpp" line="179"/>
-        <location filename="../gui/memory_widget.cpp" line="188"/>
+        <location filename="../gui/memory_widget.cpp" line="210"/>
+        <location filename="../gui/memory_widget.cpp" line="218"/>
         <source>Swap</source>
         <translation>ئالماشتۇرۇش</translation>
     </message>
     <message>
-        <location filename="../gui/memory_widget.cpp" line="180"/>
+        <location filename="../gui/memory_widget.cpp" line="211"/>
         <source>Not enabled</source>
         <translation>قوزغىتىلمىدى</translation>
     </message>
@@ -77,22 +67,22 @@
 <context>
     <name>Net.Widget</name>
     <message>
-        <location filename="../gui/net_widget.cpp" line="259"/>
+        <location filename="../gui/net_widget.cpp" line="271"/>
         <source>Download</source>
         <translation>چۈشۈرۈش</translation>
     </message>
     <message>
-        <location filename="../gui/net_widget.cpp" line="260"/>
+        <location filename="../gui/net_widget.cpp" line="272"/>
         <source>Total received</source>
         <translation>جەمئىي قوبۇل قىلىنغىنى</translation>
     </message>
     <message>
-        <location filename="../gui/net_widget.cpp" line="262"/>
+        <location filename="../gui/net_widget.cpp" line="274"/>
         <source>Total sent</source>
         <translation>جەمئىي ئەۋەتىلگىنى</translation>
     </message>
     <message>
-        <location filename="../gui/net_widget.cpp" line="261"/>
+        <location filename="../gui/net_widget.cpp" line="273"/>
         <source>Upload</source>
         <translation>يۈكلەش</translation>
     </message>
@@ -100,8 +90,9 @@
 <context>
     <name>NetWidget</name>
     <message>
-        <location filename="../gui/net_widget.cpp" line="232"/>
-        <location filename="../gui/net_widget.cpp" line="235"/>
+        <location filename="../gui/net_widget.cpp" line="241"/>
+        <location filename="../gui/net_widget.cpp" line="243"/>
+        <location filename="../gui/net_widget.cpp" line="247"/>
         <source>Network</source>
         <translation>تور</translation>
     </message>
@@ -109,37 +100,37 @@
 <context>
     <name>Process.Priority</name>
     <message>
-        <location filename="../process/process.cpp" line="67"/>
+        <location filename="../process/process.cpp" line="54"/>
         <source>Very high</source>
         <translation>بەك ئېگىز</translation>
     </message>
     <message>
-        <location filename="../process/process.cpp" line="68"/>
+        <location filename="../process/process.cpp" line="55"/>
         <source>High</source>
         <translation>ئېگىز</translation>
     </message>
     <message>
-        <location filename="../process/process.cpp" line="69"/>
+        <location filename="../process/process.cpp" line="56"/>
         <source>Normal</source>
         <translation>نورمال</translation>
     </message>
     <message>
-        <location filename="../process/process.cpp" line="70"/>
+        <location filename="../process/process.cpp" line="57"/>
         <source>Low</source>
         <translation>تۆۋەن</translation>
     </message>
     <message>
-        <location filename="../process/process.cpp" line="71"/>
+        <location filename="../process/process.cpp" line="58"/>
         <source>Very low</source>
         <translation>بەك تۆۋەن</translation>
     </message>
     <message>
-        <location filename="../process/process.cpp" line="72"/>
+        <location filename="../process/process.cpp" line="59"/>
         <source>Custom</source>
         <translation>بەلگىلەش</translation>
     </message>
     <message>
-        <location filename="../process/process.cpp" line="73"/>
+        <location filename="../process/process.cpp" line="60"/>
         <source>Invalid</source>
         <translation>ئىناۋەتسىز</translation>
     </message>
@@ -147,32 +138,32 @@
 <context>
     <name>Process.Signal</name>
     <message>
-        <location filename="../process/process_db.cpp" line="162"/>
+        <location filename="../process/process_db.cpp" line="168"/>
         <source>Failed to end process</source>
         <translation>جەرياننى ئاخىرلاشتۇرمىدى</translation>
     </message>
     <message>
-        <location filename="../process/process_db.cpp" line="165"/>
+        <location filename="../process/process_db.cpp" line="171"/>
         <source>Failed to pause process</source>
         <translation>جەرياننى توختىتالمىدى</translation>
     </message>
     <message>
-        <location filename="../process/process_db.cpp" line="168"/>
+        <location filename="../process/process_db.cpp" line="174"/>
         <source>Failed to resume process</source>
         <translation>جەرياننى ئەسلىگە كەلتۈرەلمىدى</translation>
     </message>
     <message>
-        <location filename="../process/process_db.cpp" line="171"/>
+        <location filename="../process/process_db.cpp" line="177"/>
         <source>Failed to kill process</source>
         <translation>جەرياننى ئۆلتۈرەلمىدى</translation>
     </message>
     <message>
-        <location filename="../process/process_db.cpp" line="174"/>
+        <location filename="../process/process_db.cpp" line="180"/>
         <source>Unknown error</source>
         <translation>نامەلۇم خاتالىق</translation>
     </message>
     <message>
-        <location filename="../process/process_db.cpp" line="224"/>
+        <location filename="../process/process_db.cpp" line="239"/>
         <source>Failed in sending signal to process</source>
         <translation>بىر تەرەپ قىلىش سىگنالى ئەۋەتىش مەغلۇب بولدى</translation>
     </message>
@@ -180,115 +171,80 @@
 <context>
     <name>Process.Table</name>
     <message>
-        <location filename="../model/process_table_model.cpp" line="175"/>
+        <location filename="../model/process_table_model.cpp" line="174"/>
         <source>No response</source>
         <translation>ھېچقانداق جاۋاب يوق</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.cpp" line="180"/>
+        <location filename="../model/process_table_model.cpp" line="179"/>
         <source>Suspend</source>
         <translation>توختىتىش</translation>
     </message>
-    <message>
-        <location filename="../process/process_name.cpp" line="96"/>
-        <location filename="../process/process_name.cpp" line="103"/>
-        <location filename="../process/process_name.cpp" line="106"/>
-        <source>Tray</source>
-        <translation>تەخسە</translation>
-    </message>
-</context>
-<context>
-    <name>Process.Table.Context.Menu</name>
-    <message>
-        <location filename="../common/common.cpp" line="76"/>
-        <source>End process</source>
-        <translation>جەرياننى ئاخىرلاشتۇرۇش</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="82"/>
-        <source>Suspend process</source>
-        <translation>جەرياننى توختىتىش</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="88"/>
-        <source>Resume process</source>
-        <translation>جەرياننى ئەسلىگە كەلتۈرۈش</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="93"/>
-        <source>Properties</source>
-        <translation>خاسلىقى</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="99"/>
-        <source>Kill process</source>
-        <translation>جەرياننى ئۆلتۈرۈش</translation>
-    </message>
 </context>
 <context>
     <name>Process.Table.Header</name>
     <message>
-        <location filename="../model/process_table_model.h" line="31"/>
+        <location filename="../model/process_table_model.h" line="16"/>
         <source>Name</source>
         <translation>ئىسمى</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="33"/>
+        <location filename="../model/process_table_model.h" line="18"/>
         <source>CPU</source>
         <translation>بىر تەرەپ قىلغۇچ</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="35"/>
+        <location filename="../model/process_table_model.h" line="20"/>
         <source>User</source>
         <translation>ئىشلەتكۈچى</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="37"/>
+        <location filename="../model/process_table_model.h" line="22"/>
         <source>Memory</source>
         <translation>ساقلىغۇ</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="38"/>
+        <location filename="../model/process_table_model.h" line="23"/>
         <source>Shared memory</source>
         <translation>ھەمبەھرىلەنگەن ئىچكى ساقلىغۇچ</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="39"/>
+        <location filename="../model/process_table_model.h" line="24"/>
         <source>Virtual memory</source>
         <translation>مەۋھۇم ئىچكى ساقلىغۇچ</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="41"/>
+        <location filename="../model/process_table_model.h" line="26"/>
         <source>Upload</source>
         <translation>يۈكلەش</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="43"/>
+        <location filename="../model/process_table_model.h" line="28"/>
         <source>Download</source>
         <translation>چۈشۈرۈش</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="45"/>
+        <location filename="../model/process_table_model.h" line="30"/>
         <source>Disk read</source>
         <translation>دىسكا ئوقۇش</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="47"/>
+        <location filename="../model/process_table_model.h" line="32"/>
         <source>Disk write</source>
         <translation>دىسكا يېزىش</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="49"/>
+        <location filename="../model/process_table_model.h" line="34"/>
         <source>PID</source>
         <translation>جەريان نومۇرى</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="51"/>
+        <location filename="../model/process_table_model.h" line="36"/>
         <source>Nice</source>
         <translation>ياخشى</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="53"/>
+        <location filename="../model/process_table_model.h" line="38"/>
         <source>Priority</source>
         <translation>ئىمتىيازى</translation>
     </message>
@@ -296,18 +252,19 @@
 <context>
     <name>ProcessWidget</name>
     <message>
-        <location filename="../gui/process_widget.cpp" line="65"/>
+        <location filename="../gui/process_widget.cpp" line="219"/>
         <source>Name</source>
         <translation>ئىسمى</translation>
     </message>
     <message>
-        <location filename="../gui/process_widget.cpp" line="72"/>
+        <location filename="../gui/process_widget.cpp" line="225"/>
         <source>CPU</source>
         <translation>بىر تەرەپ قىلغۇچ</translation>
     </message>
     <message>
-        <location filename="../gui/process_widget.cpp" line="182"/>
-        <location filename="../gui/process_widget.cpp" line="185"/>
+        <location filename="../gui/process_widget.cpp" line="203"/>
+        <location filename="../gui/process_widget.cpp" line="205"/>
+        <location filename="../gui/process_widget.cpp" line="209"/>
         <source>Processes</source>
         <translation>جەريانلار</translation>
     </message>
@@ -315,61 +272,9 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../system/cpu_set.cpp" line="267"/>
+        <location filename="../system/cpu_set.cpp" line="253"/>
         <source>Not support</source>
         <translation>قوللىمايدۇ</translation>
     </message>
 </context>
-<context>
-    <name>Service.Table.Context.Menu</name>
-    <message>
-        <location filename="../common/common.cpp" line="113"/>
-        <source>Start</source>
-        <translation>باشلاش</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="118"/>
-        <source>Stop</source>
-        <translation>توختاڭ</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="123"/>
-        <source>Restart</source>
-        <translation>قايتا قوزغىتىڭ</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="128"/>
-        <source>Refresh</source>
-        <translation>يېڭىلاش</translation>
-    </message>
-</context>
-<context>
-    <name>Title.Bar.Context.Menu</name>
-    <message>
-        <location filename="../common/common.cpp" line="69"/>
-        <source>Force end application</source>
-        <translation>قوللىنىشچان پروگراممىنى كۈچلەندۈرۈش</translation>
-    </message>
-</context>
-<context>
-    <name>Title.Bar.Search</name>
-    <message>
-        <location filename="../common/common.cpp" line="54"/>
-        <source>Search</source>
-        <translation>ئىزدەش</translation>
-    </message>
-</context>
-<context>
-    <name>Title.Bar.Switch</name>
-    <message>
-        <location filename="../common/common.cpp" line="63"/>
-        <source>Processes</source>
-        <translation>جەريانلار</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="108"/>
-        <source>Services</source>
-        <translation>مۇلازىمەتلەر</translation>
-    </message>
-</context>
-</TS>
\ No newline at end of file
+</TS>
